@@ -6,7 +6,7 @@ use vars qw( $session $DefaultClass @EXPORT  @ISA $defaultconfig);
 @CGI::LZE::Session::EXPORT = qw(loadSession saveSession $session);
 use CGI::LZE::Config;
 @CGI::LZE::Session::ISA     = qw(Exporter CGI::LZE::Config);
-$CGI::LZE::Session::VERSION = '0.25';
+$CGI::LZE::Session::VERSION = '0.26';
 $DefaultClass               = 'CGI::LZE::Session' unless defined $CGI::LZE::Session::DefaultClass;
 $defaultconfig              = '%CONFIG%';
 
@@ -25,12 +25,6 @@ session for CGI::LZE.
 
 loadConfig() saveSession() $session
 
-=head2
-
-required Modules
-
-Data::Dumper
-
 =head1 Public
 
 =head2 new
