@@ -6,7 +6,7 @@ use vars qw($settings $DefaultClass @EXPORT  @ISA $defaultconfig);
 @CGI::LZE::Settings::EXPORT = qw(loadSettings saveSettings $settings);
 use CGI::LZE::Config;
 @ISA                         = qw(Exporter CGI::LZE::Config);
-$CGI::LZE::Settings::VERSION = '0.25';
+$CGI::LZE::Settings::VERSION = '0.26';
 $DefaultClass                = 'CGI::LZE::Settings' unless defined $CGI::LZE::Settings::DefaultClass;
 $defaultconfig               = '%CONFIG%';
 
@@ -16,6 +16,20 @@ CGI::LZE::Settings
 
 =head1 SYNOPSIS
 
+        use CGI::LZE::Settings;
+
+        use vars qw($settings);
+
+        *settings = \$CGI::LZE::Settings::settings;
+
+        loadSettings('./config.pl');
+
+        print $settings->{key};
+
+        $settings->{key} = 'value';
+
+        saveSettings("./config.pl");
+
 
 =head1 DESCRIPTION
 
@@ -25,12 +39,6 @@ settings for CGI::LZE.
 
 loadSettings() saveSettings() $settings
 
-=head2
-
-required Modules
-
-Data::Dumper
-
 =head1 Public
 
 =head2 new()
@@ -77,4 +85,26 @@ sub getSelf {
         return (defined($_[0]) && (ref($_[0]) eq 'CGI::LZE::Settings' || UNIVERSAL::isa($_[0], 'CGI::LZE::Settings'))) ? @_ : ($CGI::LZE::Settings::DefaultClass->new, @_);
 }
 
+=head2 see Also
+
+L<CGI> L<CGI::LZE::Actions> L<CGI::LZE::Translate> L<CGI::LZE::Settings> L<CGI::LZE::Config>
+
+=head1 AUTHOR
+
+Dirk Lindner <lindnerei@o2online.de>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2005-2008 by Hr. Dirk Lindner
+
+This program is free software; you can redistribute it and/or
+modify it under the terms of the GNU Lesser General Public License
+as published by the Free Software Foundation; 
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU Lesser General Public License for more details.
+
+=cut
+
 1;
