@@ -6,7 +6,7 @@ use vars qw($ACCEPT_LANGUAGE $lang $DefaultClass @EXPORT  @ISA $defaultconfig);
 @CGI::LZE::Translate::EXPORT = qw(loadTranslate saveTranslate $lang);
 use CGI::LZE::Config;
 @ISA                          = qw(Exporter CGI::LZE::Config);
-$CGI::LZE::Translate::VERSION = '0.25';
+$CGI::LZE::Translate::VERSION = '0.26';
 $DefaultClass                 = 'CGI::LZE::Translate' unless defined $CGI::LZE::Translate::DefaultClass;
 $defaultconfig                = '%CONFIG%';
 
@@ -16,14 +16,23 @@ CGI::LZE::Translate
 
 =head1 SYNOPSIS
 
+        use CGI::LZE::Translate;
+
+        use vars qw($lang);
+
+        loadTranslate("/srv/www/cgi-bin/config/translate.pl");
+
+        *lang = \$CGI::LZE::Translate::lang;
+
+        print $lang->{de}{firstname};  #'Vorname'
 
 =head1 DESCRIPTION
 
-Translate for LZE.
+Translations for CGI::LZE.
 
 =head2 EXPORT
 
-loadTranslate() saveTranslate()
+loadTranslate() saveTranslate() $lang
 
 =head1 Public
 
@@ -38,7 +47,7 @@ sub new {
         return $self;
 }
 
-=head2 Public loadTranslate()
+=head2 loadTranslate()
 
 =cut
 
@@ -50,7 +59,7 @@ sub loadTranslate {
         }
 }
 
-=head2 Public saveTranslate()
+=head2  saveTranslate()
 
 =cut
 
@@ -71,6 +80,10 @@ sub getSelf {
         return (defined($_[0]) && (ref($_[0]) eq 'CGI::LZE::Translate' || UNIVERSAL::isa($_[0], 'CGI::LZE::Translate'))) ? @_ : ($CGI::LZE::Translate::DefaultClass->new, @_);
 }
 
+=head2 see Also
+
+L<CGI> L<CGI::LZE> L<CGI::LZE::Actions> L<CGI::LZE::Translate> L<CGI::LZE::Settings> L<CGI::LZE::Config>
+
 =head1 AUTHOR
 
 Dirk Lindner <lindnerei@o2online.de>
